# Zotomatic ドキュメント (日本語)

Zotomatic は、研究論文の PDF を起点に、書誌情報や本文の抽出結果をもとにして、ユーザー定義のテンプレートに従って Markdown ノートを自動生成する CLI ツールです。

Zotero で管理されている論文 PDF からは、著者・タイトル・アブストラクトなどのメタデータを取得して文献情報が反映されたノートを生成できます。一方で、Zotero 管理外の PDF に対しても、最低限の情報を用いたノート生成が可能です。

さらに Zotomatic は LLM と任意で連携し、論文内容の要約やタグ生成を指定言語で行い、その結果をノートに挿入できます。
※ 言語ごとの出力品質や正確性は、利用する LLM に依存します。

生成されるノートは単なる Markdown ファイルであり、テンプレートは完全にユーザーが自由に定義できます。そのため、Obsidian をはじめとする任意のエディタやナレッジ管理ツールで利用できます。


## 目次

- [スタートガイド](getting-started.md)
- [設定リファレンス](configuration.md)
- [CLIリファレンス](cli.md)

## まず読むなら

- 最初の導入は [スタートガイド](getting-started.md)
- 設定値の全体像は [設定リファレンス](configuration.md)
- コマンド一覧は [CLIリファレンス](cli.md)
